@@ -2,14 +2,21 @@ package helpers
 
 import (
 	"bytes"
+	"context"
+	"fmt"
+	"io/ioutil"
 	"net/http"
 	"net/http/httptest"
+	"net/url"
 	"os"
 	"testing"
 	"time"
 
 	"github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
+	"gocloud.dev/blob"
+	"gocloud.dev/blob/fileblob"
 
 	"gitlab.com/gitlab-org/gitlab-runner/helpers"
 )
@@ -18,33 +25,35 @@ const cacheArchiverArchive = "archive.zip"
 const cacheArchiverTestArchivedFile = "archive_file"
 
 func TestCacheArchiverIsUpToDate(t *testing.T) {
-	writeTestFile(t, cacheArchiverTestArchivedFile)
-	defer os.Remove(cacheArchiverTestArchivedFile)
+	OnEachZipArchiver(t, func(t *testing.T) {
+		writeTestFile(t, cacheArchiverTestArchivedFile)
+		defer os.Remove(cacheArchiverTestArchivedFile)
 
-	defer os.Remove(cacheArchiverArchive)
-	cmd := CacheArchiverCommand{
-		File: cacheArchiverArchive,
-		fileArchiver: fileArchiver{
-			Paths: []string{
-				cacheArchiverTestArchivedFile,
+		defer os.Remove(cacheArchiverArchive)
+		cmd := CacheArchiverCommand{
+			File: cacheArchiverArchive,
+			fileArchiver: fileArchiver{
+				Paths: []string{
+					cacheArchiverTestArchivedFile,
+				},
 			},
-		},
-	}
-	cmd.Execute(nil)
-	fi, _ := os.Stat(cacheArchiverArchive)
-	cmd.Execute(nil)
-	fi2, _ := os.Stat(cacheArchiverArchive)
-	assert.Equal(t, fi.ModTime(), fi2.ModTime(), "archive is up to date")
+		}
+		cmd.Execute(nil)
+		fi, _ := os.Stat(cacheArchiverArchive)
+		cmd.Execute(nil)
+		fi2, _ := os.Stat(cacheArchiverArchive)
+		assert.Equal(t, fi.ModTime(), fi2.ModTime(), "archive is up to date")
 
-	// We need to wait one second, since the FS doesn't save milliseconds
-	time.Sleep(time.Second)
+		// We need to wait one second, since the FS doesn't save milliseconds
+		time.Sleep(time.Second)
 
-	err := os.Chtimes(cacheArchiverTestArchivedFile, time.Now(), time.Now())
-	assert.NoError(t, err)
+		err := os.Chtimes(cacheArchiverTestArchivedFile, time.Now(), time.Now())
+		assert.NoError(t, err)
 
-	cmd.Execute(nil)
-	fi3, _ := os.Stat(cacheArchiverArchive)
-	assert.NotEqual(t, fi.ModTime(), fi3.ModTime(), "archive should get updated")
+		cmd.Execute(nil)
+		fi3, _ := os.Stat(cacheArchiverArchive)
+		assert.NotEqual(t, fi.ModTime(), fi3.ModTime(), "archive should get updated")
+	})
 }
 
 func TestCacheArchiverForIfNoFileDefined(t *testing.T) {
@@ -133,6 +142,33 @@ func TestCacheArchiverRemoteServer(t *testing.T) {
 	})
 }
 
+func TestCacheArchiverGoCloudRemoteServer(t *testing.T) {
+	mux, bucketDir, cleanup := setupGoCloudFileBucket(t, "testblob")
+	defer cleanup()
+
+	objectName := "path/to/cache.zip"
+
+	testData := "hello world\n"
+	err := ioutil.WriteFile(cacheArchiverArchive, []byte(testData), 0600)
+	require.NoError(t, err)
+	defer os.Remove(cacheArchiverArchive)
+
+	removeHook := helpers.MakeFatalToPanic()
+	defer removeHook()
+	os.Remove(cacheExtractorArchive)
+	cmd := CacheArchiverCommand{
+		File:       cacheArchiverArchive,
+		GoCloudURL: fmt.Sprintf("testblob://bucket/" + objectName),
+		Timeout:    0,
+		mux:        mux,
+	}
+	assert.NotPanics(t, func() {
+		cmd.Execute(nil)
+	})
+
+	goCloudObjectExists(t, bucketDir, objectName)
+}
+
 func TestCacheArchiverRemoteServerWithHeaders(t *testing.T) {
 	ts := httptest.NewServer(http.HandlerFunc(testCacheUploadWithCustomHeaders))
 	defer ts.Close()
@@ -191,3 +227,37 @@ func TestCacheArchiverRemoteServerFailOnInvalidServer(t *testing.T) {
 	_, err := os.Stat(cacheExtractorTestArchivedFile)
 	assert.Error(t, err)
 }
+
+type dirOpener struct {
+	tmpDir string
+}
+
+func (o *dirOpener) OpenBucketURL(_ context.Context, u *url.URL) (*blob.Bucket, error) {
+	return fileblob.OpenBucket(o.tmpDir, nil)
+}
+
+func setupGoCloudFileBucket(t *testing.T, scheme string) (m *blob.URLMux, bucketDir string, cleanup func()) {
+	tmpDir, err := ioutil.TempDir("", "test-bucket")
+	require.NoError(t, err)
+
+	mux := new(blob.URLMux)
+	fake := &dirOpener{tmpDir: tmpDir}
+	mux.RegisterBucket(scheme, fake)
+	cleanup = func() {
+		os.RemoveAll(tmpDir)
+	}
+
+	return mux, tmpDir, cleanup
+}
+
+func goCloudObjectExists(t *testing.T, bucketDir string, objectName string) {
+	bucket, err := fileblob.OpenBucket(bucketDir, nil)
+	require.NoError(t, err)
+
+	ctx, cancel := context.WithCancel(context.Background())
+	defer cancel()
+
+	exists, err := bucket.Exists(ctx, objectName)
+	require.NoError(t, err)
+	assert.True(t, exists)
+}
