@@ -1,6 +1,7 @@
 package helpers
 
 import (
+	"context"
 	"io"
 	"io/ioutil"
 	"net/http"
@@ -11,8 +12,8 @@ import (
 	"github.com/sirupsen/logrus"
 	"github.com/urfave/cli"
 
+	"gitlab.com/gitlab-org/gitlab-runner/commands/helpers/archive"
 	"gitlab.com/gitlab-org/gitlab-runner/common"
-	"gitlab.com/gitlab-org/gitlab-runner/helpers/archives"
 	url_helpers "gitlab.com/gitlab-org/gitlab-runner/helpers/url"
 	"gitlab.com/gitlab-org/gitlab-runner/log"
 )
@@ -51,7 +52,7 @@ func (c *CacheExtractorCommand) download(_ int) error {
 		return err
 	}
 
-	defer resp.Body.Close()
+	defer func() { _ = resp.Body.Close() }()
 
 	upToDate, date := checkIfUpToDate(c.File, resp)
 	if upToDate {
@@ -63,8 +64,10 @@ func (c *CacheExtractorCommand) download(_ int) error {
 	if err != nil {
 		return err
 	}
-	defer os.Remove(file.Name())
-	defer file.Close()
+	defer func() {
+		_ = file.Close()
+		_ = os.Remove(file.Name())
+	}()
 
 	logrus.Infoln("Downloading", filepath.Base(c.File), "from", url_helpers.CleanURL(c.URL))
 	_, err = io.Copy(file, resp.Body)
@@ -96,17 +99,22 @@ func (c *CacheExtractorCommand) getCache() (*http.Response, error) {
 	}
 
 	if resp.StatusCode == http.StatusNotFound {
-		resp.Body.Close()
+		_ = resp.Body.Close()
 		return nil, os.ErrNotExist
 	}
 
 	return resp, retryOnServerError(resp)
 }
 
-func (c *CacheExtractorCommand) Execute(context *cli.Context) {
+func (c *CacheExtractorCommand) Execute(cliContext *cli.Context) {
 	log.SetRunnerFormatter()
 
-	if len(c.File) == 0 {
+	wd, err := os.Getwd()
+	if err != nil {
+		logrus.Fatalln("Unable to get working directory")
+	}
+
+	if c.File == "" {
 		logrus.Fatalln("Missing cache file")
 	}
 
@@ -116,20 +124,40 @@ func (c *CacheExtractorCommand) Execute(context *cli.Context) {
 			logrus.Fatalln(err)
 		}
 	} else {
-		logrus.Infoln("No URL provided, cache will not be downloaded from shared cache server. Instead a local version of cache will be extracted.")
+		logrus.Infoln(
+			"No URL provided, cache will not be downloaded from shared cache server. " +
+				"Instead a local version of cache will be extracted.")
 	}
 
-	err := archives.ExtractZipFile(c.File)
-	if err != nil && !os.IsNotExist(err) {
+	f, size, err := openZip(c.File)
+	if os.IsNotExist(err) {
+		return
+	}
+	if err != nil {
+		logrus.Fatalln(err)
+	}
+	defer f.Close()
+
+	extractor, err := archive.NewExtractor(archive.Zip, f, size, wd)
+	if err != nil {
+		logrus.Fatalln(err)
+	}
+
+	err = extractor.Extract(context.Background())
+	if err != nil {
 		logrus.Fatalln(err)
 	}
 }
 
 func init() {
-	common.RegisterCommand2("cache-extractor", "download and extract cache artifacts (internal)", &CacheExtractorCommand{
-		retryHelper: retryHelper{
-			Retry:     2,
-			RetryTime: time.Second,
+	common.RegisterCommand2(
+		"cache-extractor",
+		"download and extract cache artifacts (internal)",
+		&CacheExtractorCommand{
+			retryHelper: retryHelper{
+				Retry:     2,
+				RetryTime: time.Second,
+			},
 		},
-	})
+	)
 }
