@@ -135,6 +135,9 @@ func TestBuildSuccessRawVariable(t *testing.T) {
 		"powershell": {
 			command: "echo $env:TEST",
 		},
+		"pwsh": {
+			command: "echo $env:TEST",
+		},
 	}
 
 	shellstest.OnEachShell(t, func(t *testing.T, shell string) {
@@ -226,44 +229,23 @@ func TestBuildUnknownFailure(t *testing.T) {
 	})
 }
 
-func TestBuildAbort(t *testing.T) {
-	shellstest.OnEachShell(t, func(t *testing.T, shell string) {
-		longRunningBuild, err := common.GetLongRunningBuild()
-		require.NoError(t, err)
-
-		build, cleanup := newBuild(t, longRunningBuild, shell)
-		defer cleanup()
-
-		abortTimer := time.AfterFunc(time.Second, func() {
-			t.Log("Interrupt")
-			build.SystemInterrupt <- os.Interrupt
-		})
-		defer abortTimer.Stop()
-
-		err = buildtest.RunBuild(t, build)
-		assert.EqualError(t, err, "aborted: interrupt")
-	})
-}
-
 func TestBuildCancel(t *testing.T) {
 	shellstest.OnEachShell(t, func(t *testing.T, shell string) {
-		longRunningBuild, err := common.GetLongRunningBuild()
-		require.NoError(t, err)
-
-		build, cleanup := newBuild(t, longRunningBuild, shell)
+		build, cleanup := newBuild(t, common.JobResponse{}, shell)
 		defer cleanup()
 
-		trace := &common.Trace{Writer: os.Stdout}
+		updateSleepForCMD := func(build *common.Build) {
+			if shell != "cmd" {
+				return
+			}
 
-		cancelTimer := time.AfterFunc(2*time.Second, func() {
-			t.Log("Cancel")
-			trace.CancelFunc()
-		})
-		defer cancelTimer.Stop()
+			resp, err := common.GetRemoteLongRunningBuildWithAfterScriptCMD()
+			require.NoError(t, err)
 
-		err = buildtest.RunBuildWithTrace(t, build, trace)
-		assert.EqualError(t, err, "canceled")
-		assert.IsType(t, err, &common.BuildError{})
+			build.JobResponse = resp
+		}
+
+		buildtest.RunBuildWithCancel(t, build.Runner, updateSleepForCMD)
 	})
 }
 
@@ -299,8 +281,11 @@ func TestBuildWithGitStrategyCloneNoCheckoutWithoutLFS(t *testing.T) {
 		defer cleanup()
 
 		build.Runner.PreCloneScript = "echo pre-clone-script"
-		build.Variables = append(build.Variables, common.JobVariable{Key: "GIT_STRATEGY", Value: "clone"})
-		build.Variables = append(build.Variables, common.JobVariable{Key: "GIT_CHECKOUT", Value: "false"})
+		build.Variables = append(
+			build.Variables,
+			common.JobVariable{Key: "GIT_STRATEGY", Value: "clone"},
+			common.JobVariable{Key: "GIT_CHECKOUT", Value: "false"},
+		)
 
 		out, err := buildtest.RunBuildReturningOutput(t, build)
 		assert.NoError(t, err)
@@ -322,8 +307,11 @@ func TestBuildWithGitSubmoduleStrategyRecursiveAndGitStrategyNone(t *testing.T)
 		build, cleanup := newBuild(t, successfulBuild, shell)
 		defer cleanup()
 
-		build.Variables = append(build.Variables, common.JobVariable{Key: "GIT_STRATEGY", Value: "none"})
-		build.Variables = append(build.Variables, common.JobVariable{Key: "GIT_SUBMODULE_STRATEGY", Value: "recursive"})
+		build.Variables = append(
+			build.Variables,
+			common.JobVariable{Key: "GIT_STRATEGY", Value: "none"},
+			common.JobVariable{Key: "GIT_SUBMODULE_STRATEGY", Value: "recursive"},
+		)
 
 		out, err := buildtest.RunBuildReturningOutput(t, build)
 		assert.NoError(t, err)
@@ -371,6 +359,7 @@ func TestBuildMultilineCommand(t *testing.T) {
 	buildGenerators := map[string]func() (common.JobResponse, error){
 		"bash":       common.GetMultilineBashBuild,
 		"powershell": common.GetMultilineBashBuildPowerShell,
+		"pwsh":       common.GetMultilineBashBuildPowerShell,
 		"cmd":        common.GetMultilineBashBuildCmd,
 	}
 
@@ -461,42 +450,56 @@ func TestBuildChangesBranchesWhenFetchingRepo(t *testing.T) {
 }
 
 func TestBuildPowerShellCatchesExceptions(t *testing.T) {
-	helpers.SkipIntegrationTests(t, "powershell")
+	for _, shell := range []string{"powershell", "pwsh"} {
+		t.Run(shell, func(t *testing.T) {
+			helpers.SkipIntegrationTests(t, shell)
 
-	successfulBuild, err := common.GetRemoteSuccessfulBuild()
-	require.NoError(t, err)
+			successfulBuild, err := common.GetRemoteSuccessfulBuild()
+			require.NoError(t, err)
 
-	build, cleanup := newBuild(t, successfulBuild, "powershell")
-	defer cleanup()
-	build.Variables = append(build.Variables, common.JobVariable{Key: "ErrorActionPreference", Value: "Stop"})
-	build.Variables = append(build.Variables, common.JobVariable{Key: "GIT_STRATEGY", Value: "fetch"})
+			build, cleanup := newBuild(t, successfulBuild, shell)
+			defer cleanup()
+			build.Variables = append(
+				build.Variables,
+				common.JobVariable{Key: "ErrorActionPreference", Value: "Stop"},
+				common.JobVariable{Key: "GIT_STRATEGY", Value: "fetch"},
+			)
 
-	out, err := buildtest.RunBuildReturningOutput(t, build)
-	assert.NoError(t, err)
-	assert.Contains(t, out, "Created fresh repository")
+			out, err := buildtest.RunBuildReturningOutput(t, build)
+			assert.NoError(t, err)
+			assert.Contains(t, out, "Created fresh repository")
 
-	out, err = buildtest.RunBuildReturningOutput(t, build)
-	assert.NoError(t, err)
-	assert.NotContains(t, out, "Created fresh repository")
-	assert.Regexp(t, "Checking out [a-f0-9]+ as", out)
+			out, err = buildtest.RunBuildReturningOutput(t, build)
+			assert.NoError(t, err)
+			assert.NotContains(t, out, "Created fresh repository")
+			assert.Regexp(t, "Checking out [a-f0-9]+ as", out)
 
-	build.Variables = append(build.Variables, common.JobVariable{Key: "ErrorActionPreference", Value: "Continue"})
-	out, err = buildtest.RunBuildReturningOutput(t, build)
-	assert.NoError(t, err)
-	assert.NotContains(t, out, "Created fresh repository")
-	assert.Regexp(t, "Checking out [a-f0-9]+ as", out)
+			build.Variables = append(
+				build.Variables,
+				common.JobVariable{Key: "ErrorActionPreference", Value: "Continue"},
+			)
+			out, err = buildtest.RunBuildReturningOutput(t, build)
+			assert.NoError(t, err)
+			assert.NotContains(t, out, "Created fresh repository")
+			assert.Regexp(t, "Checking out [a-f0-9]+ as", out)
 
-	build.Variables = append(build.Variables, common.JobVariable{Key: "ErrorActionPreference", Value: "SilentlyContinue"})
-	out, err = buildtest.RunBuildReturningOutput(t, build)
-	assert.NoError(t, err)
-	assert.NotContains(t, out, "Created fresh repository")
-	assert.Regexp(t, "Checking out [a-f0-9]+ as", out)
+			build.Variables = append(
+				build.Variables,
+				common.JobVariable{Key: "ErrorActionPreference", Value: "SilentlyContinue"},
+			)
+			out, err = buildtest.RunBuildReturningOutput(t, build)
+			assert.NoError(t, err)
+			assert.NotContains(t, out, "Created fresh repository")
+			assert.Regexp(t, "Checking out [a-f0-9]+ as", out)
+		})
+	}
 }
 
 func TestBuildOnCustomDirectory(t *testing.T) {
 	commands := map[string]string{
 		"bash":       "pwd",
 		"powershell": "pwd",
+		"pwsh":       "pwd",
 	}
 
 	tests := map[string]bool{
