@@ -11,6 +11,7 @@ import (
 	"github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/mock"
+	"github.com/stretchr/testify/require"
 
 	"gitlab.com/gitlab-org/gitlab-runner/executors/docker/internal/wait"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/docker"
@@ -37,6 +38,8 @@ func TestDockerLinuxSetter_Set(t *testing.T) {
 	containerCmdMatcher := mock.MatchedBy(func(cfg *container.Config) bool {
 		assert.Equal(t, helperImageID, cfg.Image)
 		assert.Len(t, cfg.Cmd, 3)
+		require.Contains(t, cfg.Labels, "foo")
+		assert.Equal(t, "bar", cfg.Labels["foo"])
 		return true
 	})
 
@@ -153,7 +156,7 @@ func TestDockerLinuxSetter_Set(t *testing.T) {
 				},
 			}
 
-			err := setter.Set(context.Background(), volume)
+			err := setter.Set(context.Background(), volume, map[string]string{"foo": "bar"})
 			assert.True(t, errors.Is(err, tt.expectedErr), "expected err %T, but got %T", tt.expectedErr, err)
 		})
 	}
