@@ -45,7 +45,12 @@ func (e *machineCredentialsUsageFakeExecutor) assertRunnerConfiguration(runnerCo
 	if e.expectedRunnerConfig.Docker != nil {
 		assert.Equal(e.t, e.expectedRunnerConfig.Docker.Image, runnerConfig.Docker.Image)
 	}
-	assert.Equal(e.t, e.expectedMachineCredentials, runnerConfig.Docker.Credentials, "Credentials should be filled with machine's credentials")
+	assert.Equal(
+		e.t,
+		e.expectedMachineCredentials,
+		runnerConfig.Docker.Credentials,
+		"Credentials should be filled with machine's credentials",
+	)
 }
 
 func (e *machineCredentialsUsageFakeExecutor) Prepare(options common.ExecutorPrepareOptions) error {
