@@ -11,6 +11,9 @@ const (
 	UseDirectDownload                    string = "FF_USE_DIRECT_DOWNLOAD"
 	SkipNoOpBuildStages                  string = "FF_SKIP_NOOP_BUILD_STAGES"
 	ShellExecutorUseLegacyProcessKill    string = "FF_SHELL_EXECUTOR_USE_LEGACY_PROCESS_KILL"
+	ResetHelperImageEntrypoint           string = "FF_RESET_HELPER_IMAGE_ENTRYPOINT"
+	UseGoCloudWithCacheArchiver          string = "FF_USE_GO_CLOUD_WITH_CACHE_ARCHIVER"
+	UseFastzip                           string = "FF_USE_FASTZIP"
 )
 
 type FeatureFlag struct {
@@ -76,6 +79,30 @@ var flags = []FeatureFlag{
 		Description: "Use the old process termination that was used prior to GitLab 13.1 where only `SIGKILL`" +
 			" was sent",
 	},
+	{
+		Name:            ResetHelperImageEntrypoint,
+		DefaultValue:    "true",
+		Deprecated:      true,
+		ToBeRemovedWith: "14.0",
+		Description: "Enables adding an ENTRYPOINT layer for Helper images imported from local Docker archives " +
+			"by the `docker` executor, in order to enable [importing of user certificate roots]" +
+			"(tls-self-signed.md#trusting-the-certificate-for-the-other-cicd-stages)",
+	},
+	{
+		Name:            UseGoCloudWithCacheArchiver,
+		DefaultValue:    "true",
+		Deprecated:      true,
+		ToBeRemovedWith: "14.0",
+		Description: "Enables the use of Go Cloud to write cache archives to object storage. " +
+			"This mode is only used by Azure Blob storage.",
+	},
+	{
+		Name:            UseFastzip,
+		DefaultValue:    "false",
+		Deprecated:      false,
+		ToBeRemovedWith: "",
+		Description:     "Fastzip is a performant archiver for cache/artifact archiving and extraction",
+	},
 }
 
 func GetAll() []FeatureFlag {
