@@ -9,6 +9,8 @@ import (
 	"strconv"
 	"strings"
 
+	"gitlab.com/gitlab-org/gitlab-runner/helpers/featureflags"
+
 	"gitlab.com/gitlab-org/gitlab-runner/cache"
 	"gitlab.com/gitlab-org/gitlab-runner/common"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/tls"
@@ -588,20 +590,18 @@ func (b *AbstractShell) addCacheUploadCommand(
 	args = append(args, archiverArgs...)
 
 	// Generate cache upload address
-	if url := cache.GetCacheUploadURL(info.Build, cacheKey); url != nil {
-		args = append(args, "--url", url.String())
-	}
+	args = append(args, getCacheUploadURL(info.Build, cacheKey)...)
 
-	httpHeaders := cache.GetCacheUploadHeaders(info.Build, cacheKey)
-	for key, values := range httpHeaders {
-		for _, value := range values {
-			args = append(args, "--header", fmt.Sprintf("%s: %s", key, value))
-		}
-	}
+	env := cache.GetCacheUploadEnv(info.Build, cacheKey)
 
 	// Execute cache-archiver command. Failure is not fatal.
 	b.guardRunnerCommand(w, info.RunnerCommand, "Creating cache", func() {
 		w.Noticef("Creating cache %s...", cacheKey)
+
+		for key, value := range env {
+			w.Variable(common.JobVariable{Key: key, Value: value})
+		}
+
 		w.IfCmdWithOutput(info.RunnerCommand, args...)
 		w.Noticef("Created cache")
 		w.Else()
@@ -610,6 +610,31 @@ func (b *AbstractShell) addCacheUploadCommand(
 	})
 }
 
+// getCacheUploadURL will first try to generate the GoCloud URL if it's
+// available then fallback to a pre-signed URL.
+func getCacheUploadURL(build *common.Build, cacheKey string) []string {
+	// Prefer Go Cloud URL if supported
+	goCloudURL := cache.GetCacheGoCloudURL(build, cacheKey)
+	if goCloudURL != nil && build.IsFeatureFlagOn(featureflags.UseGoCloudWithCacheArchiver) {
+		return []string{"--gocloud-url", goCloudURL.String()}
+	}
+
+	uploadURL := cache.GetCacheUploadURL(build, cacheKey)
+	if uploadURL == nil {
+		return []string{}
+	}
+
+	urlArgs := []string{"--url", uploadURL.String()}
+	httpHeaders := cache.GetCacheUploadHeaders(build, cacheKey)
+	for key, values := range httpHeaders {
+		for _, value := range values {
+			urlArgs = append(urlArgs, "--header", fmt.Sprintf("%s: %s", key, value))
+		}
+	}
+
+	return urlArgs
+}
+
 func (b *AbstractShell) writeUploadArtifact(w ShellWriter, info common.ShellScriptInfo, artifact common.Artifact) bool {
 	args := []string{
 		"artifacts-uploader",
@@ -735,14 +760,21 @@ func (b *AbstractShell) writeArchiveCacheOnFailureScript(w ShellWriter, info com
 }
 
 func (b *AbstractShell) writeCleanupFileVariablesScript(w ShellWriter, info common.ShellScriptInfo) error {
+	skipCleanupFileVariables := true
+
 	for _, variable := range info.Build.GetAllVariables() {
 		if !variable.File {
 			continue
 		}
 
+		skipCleanupFileVariables = false
 		w.RmFile(w.TmpFile(variable.Key))
 	}
 
+	if skipCleanupFileVariables {
+		return common.ErrSkipBuildStage
+	}
+
 	return nil
 }
 
